#ifndef COMMENTDELEGATE_H
#define COMMENTDELEGATE_H

#include <QStyledItemDelegate>

class QPainter;

class CommentDelegate : public QStyledItemDelegate
{
    Q_OBJECT
public:
    explicit CommentDelegate(QObject *parent);
    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
    bool editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option, const QModelIndex &index);
    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;

signals:
    void showUserChannel(const QModelIndex &index);
//    void getInitialComment(int row);
};

#endif // COMMENTDELEGATE_H
